module AFCSalesforce
  class Borrower < Base
    attr_accessor :city,
                  :company_name,
                  :email,
                  :first_name,
                  :income_type,
                  :last_name,
                  :marital_status,
                  :middle_name,
                  :phone,
                  :session_uuid,
                  :ssn,
                  :state,
                  :street,
                  :suffix,
                  :va_dependent_ages,
                  :va_dependent_count,
                  :velo__status__c,
                  :x1_prev_emp_from,
                  :x2_prev_emp_from,
                  :x1_prev_emp_monthly_income,
                  :x2_prev_emp_monthly_income,
                  :x1_prev_emp_name,
                  :x2_prev_emp_name,
                  :x1_prev_emp_to,
                  :x2_prev_emp_to,
                  :x1_residence_city,
                  :x1_residence_state,
                  :x1_residence_street,
                  :x1_residence_zip,
                  :x2_residence_city,
                  :x2_residence_state,
                  :x2_residence_street,
                  :x2_residence_zip,
                  :x3_residence_city,
                  :x3_residence_state,
                  :x3_residence_street,
                  :x3_residence_zip,
                  :zip

    set_as_integer :monthly_income,
                   :yearly_income,
                   :years_on_job

    set_as_boolean :is_primary,
                   :is_self_employed

    set_as_date :birthdate

    def to_h
      AFCSalesforce::Models::Contact.new(
        additional_income_type__c: @income_type,
        birthdate: @birthdate,
        bor_company_name__c: @company_name,
        email: @email,
        firstname: @first_name,
        is_self_employed__c: @is_self_employed,
        lastname: @last_name,
        mailingcity: @city,
        mailingpostalcode: @zip,
        mailingstate: @state,
        mailingstreet: @street,
        marital_status__c: @marital_status,
        middle_name__c: @middle_name,
        monthly_income__c: @monthly_income,
        phone: @phone,
        primary_borrower__c: @is_primary,
        session_uuid__c: @session_uuid,
        ssn__c: @ssn,
        suffix__c: @suffix,
        va_dependent_ages__c: @va_dependent_ages,
        va_dependent_count__c: @va_dependent_count,
        velo__status__c: @velo__status__c,
        x1_prev_emp_from__c: @x1_prev_emp_from,
        x2_prev_emp_from__c: @x2_prev_emp_from,
        x1_prev_emp_monthly_income__c: @x1_prev_emp_monthly_income,
        x2_prev_emp_monthly_income__c: @x2_prev_emp_monthly_income,
        x1_prev_emp_name__c: @x1_prev_emp_name,
        x2_prev_emp_name__c: @x2_prev_emp_name,
        x1_prev_emp_to__c: @x1_prev_emp_to,
        x2_prev_emp_to__c: @x2_prev_emp_to,
        x1_residence_city__c: @x1_residence_city,
        x1_residence_state__c: @x1_residence_state,
        x1_residence_street__c: @x1_residence_street,
        x1_residence_zip__c: @x1_residence_zip,
        x2_residence_city__c: @x2_residence_city,
        x2_residence_state__c: @x2_residence_state,
        x2_residence_street__c: @x2_residence_street,
        x2_residence_zip__c: @x2_residence_zip,
        x3_residence_city__c: @x3_residence_city,
        x3_residence_state__c: @x3_residence_state,
        x3_residence_street__c: @x3_residence_street,
        x3_residence_zip__c: @x3_residence_zip,
        yearly_income__c: @yearly_income,
        years_on_the_job__c: @years_on_job
      ).to_h
    end
  end
end
