module AFCSalesforce
  module Forms
    class AgentReferral
      attr_accessor :lead, :ahc_realtor

      def initialize(options={})
        @lead        = options[:lead]
        @ahc_realtor = options[:ahc_realtor]
      end

      def valid?
        validator = AgentReferralValidator.new(self)
        validator.valid?
      end

      def validate!
        validator = AgentReferralValidator.new(self)
        if validator.valid?
          return true
        else
          return validator.errors
        end
      end

      def salesforce_hash
        {
          short_lead: {
            lead: @lead.to_h
          }
        }
      end

      def send_to_salesforce
        Restforce.new(
          username:                AFCSalesforce.configuration.salesforce_username,
          password:                AFCSalesforce.configuration.salesforce_password,
          security_token:          AFCSalesforce.configuration.salesforce_security_token,
          client_id:               AFCSalesforce.configuration.salesforce_client_id,
          client_secret:           AFCSalesforce.configuration.salesforce_client_secret,
          api_version:             AFCSalesforce.configuration.salesforce_api_version,
          host:                    AFCSalesforce.configuration.salesforce_host,
          authentication_callback: AFCSalesforce.configuration.salesforce_authentication_callback
        ).post(URI('/services/apexrest/v1/lead_form'), salesforce_hash)
      end
    end

    class AgentReferralValidator < AFCSalesforce::Tools::Validation::Validator
      include AFCSalesforce::Tools::Validation
      rule :lead, [{instance_of: AFCSalesforce::Lead}, :not_nil]
      rule :ahc_realtor, [{instance_of: AFCSalesforce::AHCRealtor}, :not_nil]
    end
  end
end
