module AFCSalesforce
  module Forms
    class LeadPlus
      attr_accessor :borrowers, :account

      def initialize(options={})
        @borrowers = options.fetch(:borrowers, [])
        @account   = options.fetch(:account, nil)
      end

      def valid?
        validator = LeadPlusValidator.new(self)
        validator.valid?
      end

      def validate!
        validator = LeadPlusValidator.new(self)
        if validator.valid?
          return true
        else
          return validator.errors
        end
      end

      def salesforce_hash
        form_hash                         = {long_form: {}}
        form_hash[:long_form][:borrowers] = @borrowers.empty? ? [] : @borrowers.map(&:to_h)
        form_hash[:long_form][:account]   = @account.to_h
        form_hash
      end

      def send_to_salesforce
        Restforce.new(
          username:                AFCSalesforce.configuration.salesforce_username,
          password:                AFCSalesforce.configuration.salesforce_password,
          security_token:          AFCSalesforce.configuration.salesforce_security_token,
          client_id:               AFCSalesforce.configuration.salesforce_client_id,
          client_secret:           AFCSalesforce.configuration.salesforce_client_secret,
          api_version:             AFCSalesforce.configuration.salesforce_api_version,
          host:                    AFCSalesforce.configuration.salesforce_host,
          authentication_callback: AFCSalesforce.configuration.salesforce_authentication_callback
        ).post(URI('/services/apexrest/v1/lead_plus_form'), salesforce_hash)
      end
    end

    class LeadPlusValidator < AFCSalesforce::Tools::Validation::Validator
      include AFCSalesforce::Tools::Validation

      rule :borrowers, [{instance_of: Array}, length: {minimum: 1}]
      rule :account, [{instance_of: AFCSalesforce::Account}, :not_nil]
    end
  end
end
