module AFCSalesforce
  module Forms
    class LongRefinance
      attr_accessor :borrowers, :account, :additional_incomes, :assets

      def initialize(options={borrowers: [], account: nil, additional_incomes: [], assets: []})
        @borrowers          = options[:borrowers]
        @account            = options[:account]
        @additional_incomes = options[:additional_incomes] || []
        @assets             = options[:assets] || []
      end

      def valid?
        validator = LongRefinanceValidator.new(self)
        validator.valid?
      end

      def validate!
        validator = LongRefinanceValidator.new(self)
        if validator.valid?
          return true
        else
          return validator.errors
        end
      end

      def salesforce_hash
        form_hash                                       = {long_refinance: {}}
        form_hash[:long_refinance][:borrowers]          = @borrowers.empty? ? [] : @borrowers.map(&:to_h)
        form_hash[:long_refinance][:account]            = @account.to_h
        form_hash[:long_refinance][:additional_incomes] = @additional_incomes.empty? ? [] : @additional_incomes.map(&:to_h)
        form_hash[:long_refinance][:assets]             = @assets.empty? ? [] : @assets.map(&:to_h)
        form_hash
      end

      def send_to_salesforce
        Restforce.new(
          username:                AFCSalesforce.configuration.salesforce_username,
          password:                AFCSalesforce.configuration.salesforce_password,
          security_token:          AFCSalesforce.configuration.salesforce_security_token,
          client_id:               AFCSalesforce.configuration.salesforce_client_id,
          client_secret:           AFCSalesforce.configuration.salesforce_client_secret,
          api_version:             AFCSalesforce.configuration.salesforce_api_version,
          host:                    AFCSalesforce.configuration.salesforce_host,
          authentication_callback: AFCSalesforce.configuration.salesforce_authentication_callback
        ).post(URI('/services/apexrest/v1/refinance_form'), salesforce_hash)
      end
    end

    class LongRefinanceValidator < AFCSalesforce::Tools::Validation::Validator
      include AFCSalesforce::Tools::Validation

      rule :borrowers, [{instance_of: Array}, length: {minimum: 1}]
      rule :account, [{instance_of: AFCSalesforce::Account}, :not_nil]
      rule :additional_incomes, instance_of: Array
      rule :assets, instance_of: Array
    end
  end
end