module AFCSalesforce
  module Tools
    class UnsupportedTypeError < StandardError; end

    class Utilities
      SUPPORTED_TYPES = [:integer, :float, :date, :boolean].freeze

      def self.parse_by_type(input, type)
        return input if input.nil?
        raise UnsupportedTypeError unless SUPPORTED_TYPES.include?(type)

        output = input
        case type
          when :integer
            output_sub   = input.to_s.sub(/,/,'')
            output_match = output_sub.match(/[0-9|\.]+/)
            output       = output_match.to_s.to_i
          when :float
            output_sub   = input.to_s.sub(/,/,'')
            output_match = output_sub.match(/[0-9|\.]+/)
            output       = output_match.to_s.to_f
          when :date
            begin
              parsed_date = Time.strptime(input, "%m/%d/%Y")
              output      = parsed_date.strftime("%Y-%m-%d")
            rescue ArgumentError => e
              output = input
            end
          when :boolean
            output = false
            if input == false || input == '0' || input == 0
              output = false
            end

            if input == true || input == '1' || input == 1
              output = true
            end
            output
        end

        return output
      end
    end
  end
end
